@@ -984,7 +984,6 @@ class TlgApp:
         elif ban_pm in last_message:
             return 'ban',''
                 
-
     def do_online(self):
         async def act(self:TlgApp):
             res = await self.client(UpdateStatusRequest(False))
@@ -996,6 +995,7 @@ class TlgApp:
             res = await self.client(UpdateStatusRequest(not online))
             return res
         return self.loop.run_until_complete(act(self))
+    
     def log_out(self):
         async def act(self:TlgApp):
             res = await self.client.log_out()
@@ -1012,4 +1012,16 @@ class TlgApp:
         async def act(self:TlgApp):
             res = await self.client(BlockRequest(uid))
             return res
-        return self.loop.run_until_complete(act(self))
\ No newline at end of file
+        return self.loop.run_until_complete(act(self))
+    
+    def get_posts(self, entity, limit:int,reverse=False):
+        '''return list of copied id'''
+        async def _get_posts():
+            out=[]
+            async for message in self.client.iter_messages(entity,limit=limit, reverse=reverse):
+                out+=[message]
+            return out
+               
+        return self.loop.run_until_complete(_get_posts())
+        
+    
\ No newline at end of file
